summaryrefslogtreecommitdiff
path: root/src/mongo/db/s/move_primary_source_manager.h
diff options
context:
space:
mode:
authorMatthew Saltz <matthew.saltz@mongodb.com>2018-05-17 16:54:21 -0400
committerMatthew Saltz <matthew.saltz@mongodb.com>2018-05-18 11:18:59 -0400
commit35e9928bf33c6270e3195a00c24fe7a09edf512e (patch)
tree95079edc09345afcc1d4373ef0599d8709bd7dfa /src/mongo/db/s/move_primary_source_manager.h
parent9ca43580864a05c6eb543b5bee8402d82bd99bc7 (diff)
downloadmongo-35e9928bf33c6270e3195a00c24fe7a09edf512e.tar.gz
SERVER-34807 Rename states in movePrimary state machine to match migration
Diffstat (limited to 'src/mongo/db/s/move_primary_source_manager.h')
-rw-r--r--src/mongo/db/s/move_primary_source_manager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/s/move_primary_source_manager.h b/src/mongo/db/s/move_primary_source_manager.h
index 0b1a4127f1c..aa13bf5a0fd 100644
--- a/src/mongo/db/s/move_primary_source_manager.h
+++ b/src/mongo/db/s/move_primary_source_manager.h
@@ -99,7 +99,7 @@ public:
* movePrimary is committed. Therefore, commitMovePrimaryMetadata must be called as soon as
* possible afterwards.
*
* Expected state: kCloneCompleted
* Resulting state: kCriticalSection on success, kDone on failure
*/
Status enterCriticalSection(OperationContext* opCtx);
@@ -146,9 +146,9 @@ private:
enum State {
kCreated,
kCloning,
- kCloneCompleted,
+ kCloneCaughtUp,
kCriticalSection,
- kCommitted,
+ kCloneCompleted,
kNeedCleanStaleData,
kDone
};
@@ -99,7 +99,7 @@ public:
* possible afterwards.
*
- * Expected state: kCloneCompleted
+ * Expected state: kCloneCaughtUp
* Resulting state: kCriticalSection on success, kDone on failure
*/